=======
Credits
=======

Development Lead
----------------

* Simon Birrer <sibirrer@gmail.com>

Contributors (alphabetic)
-------------------------

* Joel Akeret
* Adam Amara
* Xuheng Ding
* Kevin Fusshoeller
* Daniel Gilman
* Felix A. Kuhn
* Felix Mayor
* Martin Millon
* Brian Nord
* Anowar Shajib
* Cyril Welschen
* Lilan Yang

SB acknowledges the support by Tommaso Treu (UCLA) and Alexandre Refregier (ETHZ) which made the development and release
of this software possible.